package App::bookmarks;

use strict;
use warnings;

our $VERSION = '0.28';

=head1 NAME

App::bookmarks - Export browser bookmarks as plain text.

=head1 DESCRIPTION

This is a stub module, see F<script/bookmarks>.

=cut

1;
